<%include file="/pageheader.html"/>

# Alert Broadcast Center

Here you can send a message to all users on all pages that are on a page using the widget API. Requires settings permission. careful if there is any digital signage on the system! To get rid of a message, just send an empty one, the newer ones clear older ones, empty means do not show.

## Send Temporary Snackbar alert to ALL users and guests using the widgets API including digital signage.

Duration(s):